tui

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 14, 2026 License: MIT Imports: 20 Imported by: 0

Documentation

Overview

Package tui implements the Bubble Tea terminal user interface for browsing and launching Copilot CLI sessions.

Index

Constants

This section is empty.

Variables

var Version = "dev"

Version is set at build time via ldflags. Defaults to "dev" for development builds.

Functions

This section is empty.

Types

type Model

type Model struct {
	// contains filtered or unexported fields
}

Model is the top-level Bubble Tea model for the Session Browser TUI.

func NewModel

func NewModel() Model

NewModel creates the root Model with default configuration.

func (Model) Init

func (m Model) Init() tea.Cmd

func (Model) Update

func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

func (Model) View

func (m Model) View() string

Directories

Path Synopsis
Package components provides reusable Bubble Tea TUI components for dispatch.
Package components provides reusable Bubble Tea TUI components for dispatch.
Package styles — icons.go defines Nerd Font icon constants and a fallback mechanism for terminals without a Nerd Font installed.
Package styles — icons.go defines Nerd Font icon constants and a fallback mechanism for terminals without a Nerd Font installed.

Jump to